@@ -10,14 +10,22 @@ pub mod client_event_loop;
 mod client_message_sorter;
 pub mod device;
 
+#[cfg(feature = "server")]
+use crate::server::ButtplugServer;
 use crate::{
   connector::{ButtplugConnector, ButtplugConnectorError, ButtplugConnectorFuture},
   core::{
     errors::{ButtplugError, ButtplugHandshakeError},
     messages::{
-      ButtplugCurrentSpecClientMessage, ButtplugCurrentSpecServerMessage,
-      ButtplugMessageSpecVersion, Ping, RequestDeviceList, RequestServerInfo, StartScanning,
-      StopAllDevices, StopScanning,
+      ButtplugCurrentSpecClientMessage,
+      ButtplugCurrentSpecServerMessage,
+      ButtplugMessageSpecVersion,
+      Ping,
+      RequestDeviceList,
+      RequestServerInfo,
+      StartScanning,
+      StopAllDevices,
+      StopScanning,
     },
   },
   util::{
@@ -26,13 +34,15 @@ use crate::{
     stream::convert_broadcast_receiver_to_stream,
   },
 };
-#[cfg(feature = "server")]
-use crate::server::ButtplugServer;
 use client_event_loop::{ButtplugClientEventLoop, ButtplugClientRequest};
 use dashmap::DashMap;
 pub use device::{
-  ButtplugClientDevice, ButtplugClientDeviceEvent, ButtplugClientDeviceMessageType, LinearCommand,
-  RotateCommand, VibrateCommand,
+  ButtplugClientDevice,
+  ButtplugClientDeviceEvent,
+  ButtplugClientDeviceMessageType,
+  LinearCommand,
+  RotateCommand,
+  VibrateCommand,
 };
 use futures::{
   future::{self, BoxFuture},
@@ -78,7 +88,7 @@ pub(crate) type ButtplugServerMessageFuture = ButtplugFuture<ButtplugServerMessa
 /// [ButtplugClientMessageFuturePair] type. We can then expect the connector to
 /// get the response from the server, match it with our message (using something
 /// like the
-/// [ClientConnectorMessageSorter][crate::connector::ClientConnectorMessageSorter]),
+/// [ClientMessageSorter][crate::client::client_message_sorter::ClientMessageSorter]),
 /// and set the reply in the waker we've sent along. This will resolve the
 /// future we're waiting on and allow us to continue execution.
 #[derive(Clone)]
@@ -142,7 +152,8 @@ pub enum ButtplugClientEvent {
   Error(ButtplugError),
 }
 
-impl Unpin for ButtplugClientEvent {}
+impl Unpin for ButtplugClientEvent {
+}
 
 /// Struct used by applications to communicate with a Buttplug Server.
 ///
@@ -152,12 +163,12 @@ impl Unpin for ButtplugClientEvent {}
 /// the API.
 ///
 /// Clients serve a few different purposes:
-/// - Managing connections to servers, thru [ButtplugClientConnector]s
+/// - Managing connections to servers, thru [ButtplugConnector]s
 /// - Emitting events received from the Server
 /// - Holding state related to the server (i.e. what devices are currently
 ///   connected, etc...)
 ///
-/// Clients are created by the [ButtplugClient::run()] method, which also
+/// Clients are created by the [ButtplugClient::new()] method, which also
 /// handles spinning up the event loop and connecting the client to the server.
 /// Closures passed to the run() method can access and use the Client object.
 pub struct ButtplugClient {
@@ -174,10 +185,12 @@ pub struct ButtplugClient {
   device_map: Arc<DashMap<u32, Arc<ButtplugClientDevice>>>,
 }
 
-unsafe impl Send for ButtplugClient {}
+unsafe impl Send for ButtplugClient {
+}
 // Not actually sure this should be sync, but trying to call handshake breaks
 // without it.
-unsafe impl Sync for ButtplugClient {}
+unsafe impl Sync for ButtplugClient {
+}
 
 impl ButtplugClient {
   pub fn new(name: &str) -> Self {
@@ -236,8 +249,7 @@ impl ButtplugClient {
         client_event_loop.run().await;
       }
       .instrument(tracing::info_span!("Client Loop Span")),
-    )
-    .unwrap();
+    );
     self.run_handshake().await
   }
 
@@ -278,7 +290,7 @@ impl ButtplugClient {
   #[cfg(feature = "server")]
   pub async fn connect_in_process(
     &self,
-    server: Option<ButtplugServer>
+    server: Option<ButtplugServer>,
   ) -> Result<(), ButtplugClientError> {
     use crate::connector::ButtplugInProcessClientConnector;
 
@@ -290,7 +302,7 @@ impl ButtplugClient {
         .server_ref()
         .device_manager()
         .add_comm_manager(BtlePlugCommunicationManagerBuilder::default())
-        .unwrap();
+        .expect("Expected that all additions will work in connect_in_process.");
     }
     #[cfg(feature = "websocket-server-manager")]
     {
@@ -299,9 +311,10 @@ impl ButtplugClient {
         .server_ref()
         .device_manager()
         .add_comm_manager(
-          WebsocketServerDeviceCommunicationManagerBuilder::default().listen_on_all_interfaces(true),
+          WebsocketServerDeviceCommunicationManagerBuilder::default()
+            .listen_on_all_interfaces(true),
         )
-        .unwrap();
+        .expect("Expected that all additions will work in connect_in_process.");
     }
     #[cfg(feature = "serial-manager")]
     {
@@ -310,7 +323,7 @@ impl ButtplugClient {
         .server_ref()
         .device_manager()
         .add_comm_manager(SerialPortCommunicationManagerBuilder::default())
-        .unwrap();
+        .expect("Expected that all additions will work in connect_in_process.");
     }
     #[cfg(feature = "lovense-connect-service-manager")]
     {
@@ -319,23 +332,24 @@ impl ButtplugClient {
         .server_ref()
         .device_manager()
         .add_comm_manager(LovenseConnectServiceCommunicationManagerBuilder::default())
-        .unwrap();
+        .expect("Expected that all additions will work in connect_in_process.");
     }
     #[cfg(feature = "lovense-dongle-manager")]
     {
       use crate::server::comm_managers::lovense_dongle::{
-        LovenseHIDDongleCommunicationManagerBuilder, LovenseSerialDongleCommunicationManagerBuilder,
+        LovenseHIDDongleCommunicationManagerBuilder,
+        LovenseSerialDongleCommunicationManagerBuilder,
       };
       connector
         .server_ref()
         .device_manager()
         .add_comm_manager(LovenseHIDDongleCommunicationManagerBuilder::default())
-        .unwrap();
+        .expect("Expected that all additions will work in connect_in_process.");
       connector
         .server_ref()
         .device_manager()
         .add_comm_manager(LovenseSerialDongleCommunicationManagerBuilder::default())
-        .unwrap();
+        .expect("Expected that all additions will work in connect_in_process.");
     }
     #[cfg(all(feature = "xinput-manager", target_os = "windows"))]
     {
@@ -344,7 +358,7 @@ impl ButtplugClient {
         .server_ref()
         .device_manager()
         .add_comm_manager(XInputDeviceCommunicationManagerBuilder::default())
-        .unwrap();
+        .expect("Expected that all additions will work in connect_in_process.");
     }
     self.connect(connector).await
   }
