@@ -8,7 +8,10 @@
 //! Device specific identification and protocol implementations.
 
 use super::protocol::{
-  add_to_protocol_map, get_default_protocol_map, ButtplugProtocol, TryCreateProtocolFunc,
+  add_to_protocol_map,
+  get_default_protocol_map,
+  ButtplugProtocol,
+  TryCreateProtocolFunc,
 };
 use crate::{
   core::{
@@ -18,7 +21,7 @@ use crate::{
   device::Endpoint,
 };
 use dashmap::DashMap;
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 use std::{
   collections::{HashMap, HashSet},
   sync::Arc,
@@ -31,24 +34,37 @@ use uuid::Uuid;
 // gonna hurt anything and making a ton of serde attributes is just going to get
 // confusing (see the messages impl).
 
-#[derive(Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct BluetoothLESpecifier {
   pub names: HashSet<String>,
+  #[serde(default, rename = "advertised-services")]
+  pub advertised_services: HashSet<Uuid>,
+  // Set of services that we may have gotten as part of the advertisement.
   pub services: HashMap<Uuid, HashMap<Endpoint, Uuid>>,
 }
 
 impl PartialEq for BluetoothLESpecifier {
   fn eq(&self, other: &Self) -> bool {
+    // If names or advertised services are found, use those automatically.
     if self.names.intersection(&other.names).count() > 0 {
       return true;
     }
+    if self
+      .advertised_services
+      .intersection(&other.advertised_services)
+      .count()
+      > 0
+    {
+      return true;
+    }
+    // Otherwise, try wildcarded names.
     for name in &self.names {
       for other_name in &other.names {
         let compare_name: &String;
         let mut wildcard: String;
         if name.ends_with('*') {
           wildcard = name.clone();
-          compare_name = &other_name;
+          compare_name = other_name;
         } else if other_name.ends_with('*') {
           wildcard = other_name.clone();
           compare_name = name;
@@ -67,11 +83,13 @@ impl PartialEq for BluetoothLESpecifier {
 }
 
 impl BluetoothLESpecifier {
-  pub fn new_from_device(name: &str) -> BluetoothLESpecifier {
-    let mut set = HashSet::new();
-    set.insert(name.to_string());
+  pub fn new_from_device(name: &str, advertised_services: &[Uuid]) -> BluetoothLESpecifier {
+    let mut name_set = HashSet::new();
+    name_set.insert(name.to_string());
+    let service_set = HashSet::from_iter(advertised_services.iter().copied());
     BluetoothLESpecifier {
-      names: set,
+      names: name_set,
+      advertised_services: service_set,
       services: HashMap::new(),
     }
   }
@@ -84,8 +102,10 @@ impl BluetoothLESpecifier {
   }
 }
 
-#[derive(Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct LovenseConnectServiceSpecifier {
+  // Needed for proper deserialization, but clippy will complain.
+  #[allow(dead_code)]
   exists: bool,
 }
 
@@ -101,8 +121,10 @@ impl PartialEq for LovenseConnectServiceSpecifier {
   }
 }
 
-#[derive(Deserialize, Debug, Clone, Copy)]
+#[derive(Serialize, Deserialize, Debug, Clone, Copy)]
 pub struct XInputSpecifier {
+  // Needed for deserialziation but unused.
+  #[allow(dead_code)]
   exists: bool,
 }
 
@@ -118,7 +140,7 @@ impl PartialEq for XInputSpecifier {
   }
 }
 
-#[derive(Deserialize, Debug, PartialEq, Clone, Copy)]
+#[derive(Serialize, Deserialize, Debug, PartialEq, Clone, Copy)]
 pub struct HIDSpecifier {
   #[serde(rename = "vendor-id")]
   vendor_id: u16,
@@ -126,7 +148,7 @@ pub struct HIDSpecifier {
   product_id: u16,
 }
 
-#[derive(Deserialize, Debug, Clone, Default)]
+#[derive(Serialize, Deserialize, Debug, Clone, Default)]
 pub struct SerialSpecifier {
   #[serde(rename = "baud-rate")]
   pub baud_rate: u32,
@@ -153,7 +175,7 @@ impl PartialEq for SerialSpecifier {
   }
 }
 
-#[derive(Deserialize, Debug, PartialEq, Clone, Copy)]
+#[derive(Serialize, Deserialize, Debug, PartialEq, Clone, Copy)]
 pub struct USBSpecifier {
   #[serde(rename = "vendor-id")]
   vendor_id: u16,
@@ -161,7 +183,7 @@ pub struct USBSpecifier {
   product_id: u16,
 }
 
-#[derive(Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct WebsocketSpecifier {
   pub names: HashSet<String>,
 }
@@ -190,7 +212,7 @@ impl WebsocketSpecifier {
   }
 }
 
-#[derive(Deserialize, Debug, PartialEq, Clone)]
+#[derive(Serialize, Deserialize, Debug, PartialEq, Clone)]
 pub enum DeviceSpecifier {
   BluetoothLE(BluetoothLESpecifier),
   HID(HIDSpecifier),
@@ -201,14 +223,14 @@ pub enum DeviceSpecifier {
   Websocket(WebsocketSpecifier),
 }
 
-#[derive(Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct ProtocolAttributes {
   identifier: Option<Vec<String>>,
   name: Option<HashMap<String, String>>,
   messages: Option<DeviceMessageAttributesMap>,
 }
 
-#[derive(Deserialize, Debug, Clone, Default)]
+#[derive(Deserialize, Serialize, Debug, Clone, Default)]
 pub struct ProtocolDefinition {
   // Can't get serde flatten specifiers into a String/DeviceSpecifier map, so
   // they're kept separate here, and we return them in get_specifiers(). Feels
@@ -392,7 +414,7 @@ impl DeviceProtocolConfiguration {
       attrs
         .identifier
         .as_ref()
-        .unwrap()
+        .expect("Identifier required as part of JSON schema.")
         .contains(&identifier.to_owned())
     }) {
       attrs
@@ -419,8 +441,14 @@ impl DeviceProtocolConfiguration {
       .entry(ButtplugDeviceMessageType::StopDeviceCmd)
       .or_insert_with(DeviceMessageAttributes::default);
 
-    // The device config JSON schema requires us to have a name map, so we can unwrap this.
-    Ok((device_attrs.name.as_ref().unwrap().clone(), attributes))
+    Ok((
+      device_attrs
+        .name
+        .as_ref()
+        .expect("Name required as part of JSON schema")
+        .clone(),
+      attributes,
+    ))
   }
 }
 
@@ -447,8 +475,14 @@ impl DeviceConfigurationManager {
     }
   }
 
-  pub fn add_protocol_definition(&self, protocol_name: &str, protocol_definition: ProtocolDefinition) {
-    self.protocol_definitions.insert(protocol_name.to_owned(), protocol_definition);
+  pub fn add_protocol_definition(
+    &self,
+    protocol_name: &str,
+    protocol_definition: ProtocolDefinition,
+  ) {
+    self
+      .protocol_definitions
+      .insert(protocol_name.to_owned(), protocol_definition);
   }
 
   pub fn remove_protocol_definition(&self, protocol_name: &str) {
@@ -474,8 +508,11 @@ impl DeviceConfigurationManager {
     self.protocol_map.contains_key(protocol_name)
   }
 
-  pub fn get_protocol_creator(&self, protocol_name: &str) -> TryCreateProtocolFunc {
-    self.protocol_map.get(protocol_name).unwrap().clone()
+  pub fn get_protocol_creator(&self, protocol_name: &str) -> Option<TryCreateProtocolFunc> {
+    self
+      .protocol_map
+      .get(protocol_name)
+      .map(|pair| *pair.value())
   }
 
   /// Provides read-only access to the internal protocol/identifier map. Mainly
@@ -495,8 +532,16 @@ impl DeviceConfigurationManager {
     );
     for config in self.protocol_definitions.iter() {
       if config.value() == specifier {
-        info!("Found protocol {:?} for specifier {:?}.", config.key(), specifier);
-        return Some((self.allow_raw_messages, config.key().clone(), config.value().clone()));
+        info!(
+          "Found protocol {:?} for specifier {:?}.",
+          config.key(),
+          specifier
+        );
+        return Some((
+          self.allow_raw_messages,
+          config.key().clone(),
+          config.value().clone(),
+        ));
       }
     }
     debug!("No protocol found for specifier {:?}.", specifier);
@@ -524,20 +569,27 @@ impl DeviceConfigurationManager {
 #[cfg(test)]
 mod test {
   use super::{
-    BluetoothLESpecifier, DeviceProtocolConfiguration, DeviceSpecifier, SerialSpecifier
+    BluetoothLESpecifier,
+    DeviceProtocolConfiguration,
+    DeviceSpecifier,
+    SerialSpecifier,
   };
-  use crate::{core::messages::ButtplugDeviceMessageType, device::configuration_manager::ProtocolDefinition, util::device_configuration::create_test_dcm};
-/*
-  #[test]
-  fn test_load_config() {
-    let config = DeviceConfigurationManager::default();
-    debug!("{:?}", config.config);
-  }
-*/
+  use crate::{
+    core::messages::ButtplugDeviceMessageType,
+    device::configuration_manager::ProtocolDefinition,
+    util::device_configuration::create_test_dcm,
+  };
+  /*
+    #[test]
+    fn test_load_config() {
+      let config = DeviceConfigurationManager::default();
+      debug!("{:?}", config.config);
+    }
+  */
   #[test]
   fn test_config_equals() {
     let config = create_test_dcm(false);
-    let launch = DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("Launch"));
+    let launch = DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("Launch", &[]));
     assert!(config.find_protocol_definitions(&launch).is_some());
   }
 
@@ -545,7 +597,7 @@ mod test {
   fn test_config_wildcard_equals() {
     let config = create_test_dcm(false);
     let lovense =
-      DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever"));
+      DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever", &[]));
     assert!(config.find_protocol_definitions(&lovense).is_some());
   }
 
@@ -553,20 +605,27 @@ mod test {
   fn test_specific_device_config_creation() {
     let config = create_test_dcm(false);
     let lovense =
-      DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever"));
-    let proto = config.find_protocol_definitions(&lovense).unwrap();
+      DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever", &[]));
+    let proto = config
+      .find_protocol_definitions(&lovense)
+      .expect("Test, assuming infallible");
     let proto_config =
       DeviceProtocolConfiguration::new(false, proto.2.defaults.clone(), proto.2.configurations);
-    let (name_map, message_map) = proto_config.get_attributes("P", &vec![]).unwrap();
+    let (name_map, message_map) = proto_config
+      .get_attributes("P", &vec![])
+      .expect("Test, assuming infallible");
     // Make sure we got the right name
-    assert_eq!(name_map.get("en-us").unwrap(), "Lovense Edge");
+    assert_eq!(
+      name_map.get("en-us").expect("Test, assuming infallible"),
+      "Lovense Edge"
+    );
     // Make sure we overwrote the default of 1
     assert_eq!(
       message_map
         .get(&ButtplugDeviceMessageType::VibrateCmd)
-        .unwrap()
+        .expect("Test, assuming infallible")
         .feature_count
-        .unwrap(),
+        .expect("Test, assuming infallible"),
       2
     );
   }
@@ -575,13 +634,20 @@ mod test {
   fn test_raw_device_config_creation() {
     let config = create_test_dcm(true);
     let lovense =
-      DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever"));
-    let proto = config.find_protocol_definitions(&lovense).unwrap();
+      DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever", &[]));
+    let proto = config
+      .find_protocol_definitions(&lovense)
+      .expect("Test, assuming infallible");
     let proto_config =
       DeviceProtocolConfiguration::new(true, proto.2.defaults.clone(), proto.2.configurations);
-    let (name_map, message_map) = proto_config.get_attributes("P", &vec![]).unwrap();
+    let (name_map, message_map) = proto_config
+      .get_attributes("P", &vec![])
+      .expect("Test, assuming infallible");
     // Make sure we got the right name
-    assert_eq!(name_map.get("en-us").unwrap(), "Lovense Edge");
+    assert_eq!(
+      name_map.get("en-us").expect("Test, assuming infallible"),
+      "Lovense Edge"
+    );
     // Make sure we overwrote the default of 1
     assert!(message_map.contains_key(&ButtplugDeviceMessageType::RawWriteCmd));
     assert!(message_map.contains_key(&ButtplugDeviceMessageType::RawReadCmd));
@@ -593,13 +659,20 @@ mod test {
   fn test_non_raw_device_config_creation() {
     let config = create_test_dcm(false);
     let lovense =
-      DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever"));
-    let proto = config.find_protocol_definitions(&lovense).unwrap();
+      DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever", &[]));
+    let proto = config
+      .find_protocol_definitions(&lovense)
+      .expect("Test, assuming infallible");
     let proto_config =
       DeviceProtocolConfiguration::new(false, proto.2.defaults.clone(), proto.2.configurations);
-    let (name_map, message_map) = proto_config.get_attributes("P", &vec![]).unwrap();
+    let (name_map, message_map) = proto_config
+      .get_attributes("P", &vec![])
+      .expect("Test, assuming infallible");
     // Make sure we got the right name
-    assert_eq!(name_map.get("en-us").unwrap(), "Lovense Edge");
+    assert_eq!(
+      name_map.get("en-us").expect("Test, assuming infallible"),
+      "Lovense Edge"
+    );
     // Make sure we overwrote the default of 1
     assert!(!message_map.contains_key(&ButtplugDeviceMessageType::RawWriteCmd));
     assert!(!message_map.contains_key(&ButtplugDeviceMessageType::RawReadCmd));
@@ -615,7 +688,7 @@ mod test {
     assert!(config
       .protocol_definitions()
       .get("nobra")
-      .unwrap()
+      .expect("Test, assuming infallible")
       .serial
       .as_ref()
       .is_some());
@@ -623,10 +696,10 @@ mod test {
       config
         .protocol_definitions()
         .get("nobra")
-        .unwrap()
+        .expect("Test, assuming infallible")
         .serial
         .as_ref()
-        .unwrap()
+        .expect("Test, assuming infallible")
         .len(),
       1
     );
@@ -636,13 +709,13 @@ mod test {
     let mut nobra_def = ProtocolDefinition::default();
     let mut serial_specifier = SerialSpecifier::default();
     serial_specifier.port = "COM1".to_owned();
-    nobra_def.serial = Some(vec!(serial_specifier));
+    nobra_def.serial = Some(vec![serial_specifier]);
     config.add_protocol_definition("nobra", nobra_def);
     assert!(config.protocol_definitions().contains_key("nobra"));
     assert!(config
       .protocol_definitions()
       .get("nobra")
-      .unwrap()
+      .expect("Test, assuming infallible")
       .serial
       .as_ref()
       .is_some());
@@ -650,20 +723,20 @@ mod test {
       config
         .protocol_definitions()
         .get("nobra")
-        .unwrap()
+        .expect("Test, assuming infallible")
         .serial
         .as_ref()
-        .unwrap()
+        .expect("Test, assuming infallible")
         .len(),
       1
     );
     assert!(config
       .protocol_definitions()
       .get("nobra")
-      .unwrap()
+      .expect("Test, assuming infallible")
       .serial
       .as_ref()
-      .unwrap()
+      .expect("Test, assuming infallible")
       .iter()
       .any(|x| x.port == "COM1"));
   }
