@@ -2,7 +2,10 @@ pub mod configuration_manager;
 pub mod protocol;
 use serde::{
   de::{self, Visitor},
-  Deserialize, Deserializer, Serialize, Serializer,
+  Deserialize,
+  Deserializer,
+  Serialize,
+  Serializer,
 };
 use std::{
   fmt::{self, Debug},
@@ -15,8 +18,15 @@ use crate::{
   core::{
     errors::ButtplugError,
     messages::{
-      self, ButtplugDeviceCommandMessageUnion, ButtplugServerMessage, DeviceMessageAttributesMap,
-      RawReadCmd, RawReading, RawSubscribeCmd, RawUnsubscribeCmd, RawWriteCmd,
+      self,
+      ButtplugDeviceCommandMessageUnion,
+      ButtplugServerMessage,
+      DeviceMessageAttributesMap,
+      RawReadCmd,
+      RawReading,
+      RawSubscribeCmd,
+      RawUnsubscribeCmd,
+      RawWriteCmd,
     },
     ButtplugResultFuture,
   },
@@ -389,6 +399,7 @@ pub trait ButtplugDeviceImplCreator: Sync + Send + Debug {
 pub struct ButtplugDevice {
   protocol: Box<dyn ButtplugProtocol>,
   device: Arc<DeviceImpl>,
+  display_name: Option<String>,
 }
 
 impl Debug for ButtplugDevice {
@@ -406,7 +417,8 @@ impl Hash for ButtplugDevice {
   }
 }
 
-impl Eq for ButtplugDevice {}
+impl Eq for ButtplugDevice {
+}
 
 impl PartialEq for ButtplugDevice {
   fn eq(&self, other: &Self) -> bool {
@@ -416,7 +428,11 @@ impl PartialEq for ButtplugDevice {
 
 impl ButtplugDevice {
   pub fn new(protocol: Box<dyn ButtplugProtocol>, device: Arc<DeviceImpl>) -> Self {
-    Self { protocol, device }
+    Self {
+      protocol,
+      device,
+      display_name: None,
+    }
   }
 
   pub fn address(&self) -> &str {
@@ -447,36 +463,29 @@ impl ButtplugDevice {
         // TODO Should we even return a config from the device_config_mgr if the
         // protocol isn't there?
         if device_config_mgr.has_protocol(&*config_name) {
-          match device_creator.try_create_device_impl(config).await {
-            Ok(device_impl) => {
-              info!(
-                address = tracing::field::display(device_impl.address()),
-                "Found Buttplug Device {}",
-                device_impl.name()
-              );
-              // If we've made it this far, we now have a connected device
-              // implementation with endpoints set up. We now need to run whatever
-              // protocol initialization might need to happen. We'll fetch a protocol
-              // creator, pass the device implementation to it, then let it do
-              // whatever it needs. For most protocols, this is a no-op. However, for
-              // devices like Lovense, some Kiiroo, etc, this can get fairly
-              // complicated.
-              let sharable_device_impl = Arc::new(device_impl);
-              match device_config_mgr.get_protocol_creator(&*config_name)(
-                sharable_device_impl.clone(),
-                device_protocol_config,
-              )
-              .await
-              {
-                Ok(protocol_impl) => Ok(Some(ButtplugDevice::new(
-                  protocol_impl,
-                  sharable_device_impl,
-                ))),
-                Err(e) => Err(e),
-              }
-            }
-            Err(e) => Err(e),
-          }
+          let device_impl = device_creator.try_create_device_impl(config).await?;
+          info!(
+            address = tracing::field::display(device_impl.address()),
+            "Found Buttplug Device {}",
+            device_impl.name()
+          );
+          // If we've made it this far, we now have a connected device
+          // implementation with endpoints set up. We now need to run whatever
+          // protocol initialization might need to happen. We'll fetch a protocol
+          // creator, pass the device implementation to it, then let it do
+          // whatever it needs. For most protocols, this is a no-op. However, for
+          // devices like Lovense, some Kiiroo, etc, this can get fairly
+          // complicated.
+          let sharable_device_impl = Arc::new(device_impl);
+          let protocol_creator_func = device_config_mgr
+            .get_protocol_creator(&*config_name)
+            .expect("Already checked for protocol existence");
+          let protocol_impl =
+            protocol_creator_func(sharable_device_impl.clone(), device_protocol_config).await?;
+          Ok(Some(ButtplugDevice::new(
+            protocol_impl,
+            sharable_device_impl,
+          )))
         } else {
           info!("Protocol {} not available", config_name);
           Ok(None)
@@ -486,6 +495,20 @@ impl ButtplugDevice {
     }
   }
 
+  pub fn set_display_name(&mut self, name: &str) {
+    info!(
+      "Adding display name {} to device {} ({})",
+      name,
+      self.name(),
+      self.address()
+    );
+    self.display_name = Some(name.to_owned());
+  }
+
+  pub fn display_name(&self) -> Option<String> {
+    self.display_name.clone()
+  }
+
   pub fn name(&self) -> String {
     // Instead of checking for raw messages at the protocol level, add the raw
     // call here, since this is the only way to access devices in the library
@@ -500,7 +523,7 @@ impl ButtplugDevice {
       ))
       .is_ok()
     {
-      format!("{} (Raw)", self.protocol.name())
+      format!("{} (Raw Messages Allowed)", self.protocol.name())
     } else {
       self.protocol.name().to_owned()
     }
