@@ -4,7 +4,9 @@ use crate::{
   core::messages::{self, ButtplugDeviceCommandMessageUnion, DeviceMessageAttributesMap},
   device::{
     protocol::{generic_command_manager::GenericCommandManager, ButtplugProtocolProperties},
-    DeviceImpl, DeviceWriteCmd, Endpoint,
+    DeviceImpl,
+    DeviceWriteCmd,
+    Endpoint,
   },
 };
 use futures::future::{self, BoxFuture};
@@ -102,22 +104,30 @@ mod test {
   use crate::{
     core::messages::{StopDeviceCmd, VibrateCmd, VibrateSubcommand},
     device::{DeviceImplCommand, DeviceWriteCmd, Endpoint},
-    server::comm_managers::test::{check_test_recv_empty, check_test_recv_value, new_bluetoothle_test_device},
+    server::comm_managers::test::{
+      check_test_recv_empty,
+      check_test_recv_value,
+      new_bluetoothle_test_device,
+    },
     util::async_manager,
   };
 
   #[test]
   pub fn test_patoo_protocol_devil() {
     async_manager::block_on(async move {
-      let (device, test_device) = new_bluetoothle_test_device("PBT821").await.unwrap();
-      let command_receiver_tx = test_device.get_endpoint_receiver(&Endpoint::Tx).unwrap();
+      let (device, test_device) = new_bluetoothle_test_device("PBT821")
+        .await
+        .expect("Test, assuming infallible");
+      let command_receiver_tx = test_device
+        .get_endpoint_receiver(&Endpoint::Tx)
+        .expect("Test, assuming infallible");
       let command_receiver_txmode = test_device
         .get_endpoint_receiver(&Endpoint::TxMode)
-        .unwrap();
+        .expect("Test, assuming infallible");
       device
         .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // We just vibe 1 so expect 2 writes (mode 0x04)
       check_test_recv_value(
         &command_receiver_tx,
@@ -133,7 +143,7 @@ mod test {
       device
         .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // no-op
       assert!(check_test_recv_empty(&command_receiver_tx));
       assert!(check_test_recv_empty(&command_receiver_txmode));
@@ -150,7 +160,7 @@ mod test {
           .into(),
         )
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // setting second vibe whilst changing vibe 1, 2 writes (mode 1)
       check_test_recv_value(
         &command_receiver_tx,
@@ -175,7 +185,7 @@ mod test {
           .into(),
         )
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // only vibe 1 changed, 2 writes, same data
       check_test_recv_value(
         &command_receiver_tx,
@@ -200,7 +210,7 @@ mod test {
           .into(),
         )
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // turn off vibe 1, 2 writes (mode 0x80)
       check_test_recv_value(
         &command_receiver_tx,
@@ -216,7 +226,7 @@ mod test {
       device
         .parse_message(StopDeviceCmd::new(0).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // stop on both, 2 writes (mode 0)
       check_test_recv_value(
         &command_receiver_tx,
@@ -234,16 +244,20 @@ mod test {
   #[test]
   pub fn test_patoo_protocol_carrot() {
     async_manager::block_on(async move {
-      let (device, test_device) = new_bluetoothle_test_device("PTVEA2601").await.unwrap();
+      let (device, test_device) = new_bluetoothle_test_device("PTVEA2601")
+        .await
+        .expect("Test, assuming infallible");
 
-      let command_receiver_tx = test_device.get_endpoint_receiver(&Endpoint::Tx).unwrap();
+      let command_receiver_tx = test_device
+        .get_endpoint_receiver(&Endpoint::Tx)
+        .expect("Test, assuming infallible");
       let command_receiver_txmode = test_device
         .get_endpoint_receiver(&Endpoint::TxMode)
-        .unwrap();
+        .expect("Test, assuming infallible");
       device
         .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // We just vibe 1 so expect 2 writes (mode 0x04)
       check_test_recv_value(
         &command_receiver_tx,
@@ -259,7 +273,7 @@ mod test {
       device
         .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // no-op
       assert!(check_test_recv_empty(&command_receiver_tx));
       assert!(check_test_recv_empty(&command_receiver_txmode));
@@ -283,7 +297,7 @@ mod test {
       device
         .parse_message(StopDeviceCmd::new(0).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       // stop on both, 2 writes (mode 0)
       check_test_recv_value(
         &command_receiver_tx,
