@@ -3,18 +3,25 @@ use crate::{
   core::{
     errors::ButtplugError,
     messages::{
-      self, ButtplugDeviceCommandMessageUnion, ButtplugDeviceMessage, DeviceMessageAttributesMap,
-      VibrateCmd, VibrateSubcommand,
+      self,
+      ButtplugDeviceCommandMessageUnion,
+      ButtplugDeviceMessage,
+      DeviceMessageAttributesMap,
+      VibrateCmd,
+      VibrateSubcommand,
     },
   },
   device::{
     protocol::{generic_command_manager::GenericCommandManager, ButtplugProtocolProperties},
-    DeviceImpl, DeviceReadCmd, DeviceWriteCmd, Endpoint,
+    DeviceImpl,
+    DeviceReadCmd,
+    DeviceWriteCmd,
+    Endpoint,
   },
 };
+use futures::future::BoxFuture;
 use std::sync::Arc;
 use tokio::sync::Mutex;
-use futures::future::BoxFuture;
 
 #[derive(ButtplugProtocolProperties)]
 pub struct Vibratissimo {
@@ -43,14 +50,12 @@ impl ButtplugProtocol for Vibratissimo {
     device_impl: Arc<DeviceImpl>,
   ) -> BoxFuture<'static, Result<Option<String>, ButtplugError>> {
     Box::pin(async move {
-
-      let mut name = device_impl.name.clone();
-      let result = device_impl.read_value(DeviceReadCmd::new(Endpoint::RxBLEModel, 128, 500)).await;
-      if result.is_ok() {
-        name = String::from_utf8(result.unwrap().data().to_vec()).unwrap_or(device_impl.name.clone());
-      }
-
-      Ok(Some(name))
+      let result = device_impl
+        .read_value(DeviceReadCmd::new(Endpoint::RxBLEModel, 128, 500))
+        .await?;
+      Ok(Some(
+        String::from_utf8(result.data().to_vec()).unwrap_or_else(|_| device_impl.name.clone()),
+      ))
     })
   }
 }
@@ -82,11 +87,11 @@ impl ButtplugProtocolCommandHandler for Vibratissimo {
       let mut fut_vec = vec![];
       if let Some(cmds) = result {
         let mut data: Vec<u8> = Vec::new();
-        for i in 0..cmds.len() {
-          data.push( cmds[i].unwrap_or(0) as u8 );
+        for cmd in cmds {
+          data.push(cmd.unwrap_or(0) as u8);
         }
         if data.len() == 1 {
-          data.push( 0x00 );
+          data.push(0x00);
         }
 
         // Put the device in write mode
@@ -95,11 +100,7 @@ impl ButtplugProtocolCommandHandler for Vibratissimo {
           vec![0x03, 0xff],
           false,
         )));
-        fut_vec.push(device.write_value(DeviceWriteCmd::new(
-          Endpoint::TxVibrate,
-          data,
-          false,
-        )));
+        fut_vec.push(device.write_value(DeviceWriteCmd::new(Endpoint::TxVibrate, data, false)));
       }
       // TODO Just use join_all here
       for fut in fut_vec {
@@ -116,25 +117,31 @@ mod test {
   use crate::{
     core::messages::{StopDeviceCmd, VibrateCmd, VibrateSubcommand},
     device::{DeviceImplCommand, DeviceWriteCmd, Endpoint},
-    server::comm_managers::test::{check_test_recv_empty, check_test_recv_value, new_bluetoothle_test_device},
+    server::comm_managers::test::{
+      check_test_recv_empty,
+      check_test_recv_value,
+      new_bluetoothle_test_device,
+    },
     util::async_manager,
   };
 
   #[test]
   pub fn test_vibratissimo_protocol_default() {
     async_manager::block_on(async move {
-      let (device, test_device) = new_bluetoothle_test_device("Vibratissimo").await.unwrap();
+      let (device, test_device) = new_bluetoothle_test_device("Vibratissimo")
+        .await
+        .expect("Test, assuming infallible");
       let command_receiver_vibrate = test_device
         .get_endpoint_receiver(&Endpoint::TxVibrate)
-        .unwrap();
+        .expect("Test, assuming infallible");
       let command_receiver_mode = test_device
         .get_endpoint_receiver(&Endpoint::TxMode)
-        .unwrap();
+        .expect("Test, assuming infallible");
 
       device
         .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       check_test_recv_value(
         &command_receiver_vibrate,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -158,14 +165,14 @@ mod test {
       device
         .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       assert!(check_test_recv_empty(&command_receiver_mode));
       assert!(check_test_recv_empty(&command_receiver_vibrate));
 
       device
         .parse_message(StopDeviceCmd::new(0).into())
         .await
-        .unwrap();
+        .expect("Test, assuming infallible");
       check_test_recv_value(
         &command_receiver_vibrate,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -191,21 +198,23 @@ mod test {
   #[ignore] // Need to be able to set BLE model info to be read on test device
   pub fn test_vibratissimo_protocol_licker() {
     async_manager::block_on(async move {
-      let (device, test_device) = new_bluetoothle_test_device("Vibratissimo").await.unwrap();
+      let (device, test_device) = new_bluetoothle_test_device("Vibratissimo")
+        .await
+        .expect("Test, assuming infallible");
       let command_receiver_vibrate = test_device
-          .get_endpoint_receiver(&Endpoint::TxVibrate)
-          .unwrap();
+        .get_endpoint_receiver(&Endpoint::TxVibrate)
+        .expect("Test, assuming infallible");
       let command_receiver_mode = test_device
-          .get_endpoint_receiver(&Endpoint::TxMode)
-          .unwrap();
+        .get_endpoint_receiver(&Endpoint::TxMode)
+        .expect("Test, assuming infallible");
 
       assert!(check_test_recv_empty(&command_receiver_mode));
       assert!(check_test_recv_empty(&command_receiver_vibrate));
 
       device
-          .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
-          .await
-          .unwrap();
+        .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
+        .await
+        .expect("Test, assuming infallible");
       check_test_recv_value(
         &command_receiver_vibrate,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -226,9 +235,9 @@ mod test {
       assert!(check_test_recv_empty(&command_receiver_mode));
 
       device
-          .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(1, 1.0)]).into())
-          .await
-          .unwrap();
+        .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(1, 1.0)]).into())
+        .await
+        .expect("Test, assuming infallible");
       check_test_recv_value(
         &command_receiver_vibrate,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -250,15 +259,15 @@ mod test {
 
       // Since we only created one subcommand, we should only receive one command.
       device
-          .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
-          .await
-          .unwrap();
+        .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
+        .await
+        .expect("Test, assuming infallible");
       assert!(check_test_recv_empty(&command_receiver_mode));
       assert!(check_test_recv_empty(&command_receiver_vibrate));
       device
-          .parse_message(StopDeviceCmd::new(0).into())
-          .await
-          .unwrap();
+        .parse_message(StopDeviceCmd::new(0).into())
+        .await
+        .expect("Test, assuming infallible");
 
       check_test_recv_value(
         &command_receiver_vibrate,
@@ -285,21 +294,23 @@ mod test {
   #[ignore] // Need to be able to set BLE model info to be read on test device
   pub fn test_vibratissimo_protocol_rabbit() {
     async_manager::block_on(async move {
-      let (device, test_device) = new_bluetoothle_test_device("Vibratissimo").await.unwrap();
+      let (device, test_device) = new_bluetoothle_test_device("Vibratissimo")
+        .await
+        .expect("Test, assuming infallible");
       let command_receiver_vibrate = test_device
-          .get_endpoint_receiver(&Endpoint::TxVibrate)
-          .unwrap();
+        .get_endpoint_receiver(&Endpoint::TxVibrate)
+        .expect("Test, assuming infallible");
       let command_receiver_mode = test_device
-          .get_endpoint_receiver(&Endpoint::TxMode)
-          .unwrap();
+        .get_endpoint_receiver(&Endpoint::TxMode)
+        .expect("Test, assuming infallible");
 
       assert!(check_test_recv_empty(&command_receiver_mode));
       assert!(check_test_recv_empty(&command_receiver_vibrate));
 
       device
-          .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
-          .await
-          .unwrap();
+        .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
+        .await
+        .expect("Test, assuming infallible");
       check_test_recv_value(
         &command_receiver_vibrate,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -320,9 +331,9 @@ mod test {
       assert!(check_test_recv_empty(&command_receiver_mode));
 
       device
-          .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(1, 1.0)]).into())
-          .await
-          .unwrap();
+        .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(1, 1.0)]).into())
+        .await
+        .expect("Test, assuming infallible");
       check_test_recv_value(
         &command_receiver_vibrate,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -343,9 +354,9 @@ mod test {
       assert!(check_test_recv_empty(&command_receiver_mode));
 
       device
-          .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(2, 1.0)]).into())
-          .await
-          .unwrap();
+        .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(2, 1.0)]).into())
+        .await
+        .expect("Test, assuming infallible");
       check_test_recv_value(
         &command_receiver_vibrate,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -367,16 +378,16 @@ mod test {
 
       // Since we only created one subcommand, we should only receive one command.
       device
-          .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
-          .await
-          .unwrap();
+        .parse_message(VibrateCmd::new(0, vec![VibrateSubcommand::new(0, 0.5)]).into())
+        .await
+        .expect("Test, assuming infallible");
       assert!(check_test_recv_empty(&command_receiver_mode));
       assert!(check_test_recv_empty(&command_receiver_vibrate));
 
       device
-          .parse_message(StopDeviceCmd::new(0).into())
-          .await
-          .unwrap();
+        .parse_message(StopDeviceCmd::new(0).into())
+        .await
+        .expect("Test, assuming infallible");
       check_test_recv_value(
         &command_receiver_vibrate,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
